@@ -1,10 +1,10 @@
-__version__ = "0.4.16"
+__version__ = "0.4.17"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(detached from v0.4.16)'
+__git_branch__ = '(detached from v0.4.17)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = '1b47da3f9b8278c46d9678b18af2abfb480ae1f3'
-__git_head_subject__ = 'TRIVIAL fix hard_install'
+__git_head_hash__ = '0907def3b153dd37953d43026ed6d331e233e135'
+__git_head_subject__ = 'Finished release v0.4.17.'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
